# Reference API

::: namedcolors.colors.NamedColor
    handler: python
    options:
      members:
        - hex
        - name
      show_root_heading: true
      show_source: true

::: namedcolors.colors.rgb_to_hex
    handler: python
    options:
      members:
        - hex
        - name
      show_root_heading: true
      show_source: true